/*****************************************************************************
 * Name:      converterconsole.cpp
 * Purpose:   Code for console version of converter
 * Created:   2008-01-06
 * Copyright: 2007,2008 Dominik Wagenfuehr <dominik.wagenfuehr@deesaster.org>
 * License:   GPLv3
 *****************************************************************************/

/**
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "../library/converterbase.h"
#include <iostream>
#include <wx/wx.h>
#include <wx/textfile.h>

// print help
void PrintHelp(char* command)
{
    std::cout << "Usage: "<< command << " -i=html/bb/moin -o=html/bb/moin [-O=blog/uu/none] filename"<< std::endl << std::endl;
}

int main(int argc, char** argv)
{
    char version[]="v8.1.12";
    wxString tempStr;

    if (argc==2)
    {
        tempStr=wxString::FromUTF8(argv[1]);

        if (tempStr.StartsWith(_T("-V")))
        {   // version
            std::cout << "HTML/BB/MoinMoin-Converter " << version << std::endl;
            std::cout << "Copyright (C) 2007,2008 Dominik Wagenfuehr <dominik.wagenfuehr@deesaster.org>" << std::endl;
            std::cout << "License: GPLv3" << std::endl << std::endl;
        }
        else if (tempStr.StartsWith(_T("-h")))
        {
            PrintHelp(argv[0]);
        }
        else
        {
            std::cout << "Need at least three arguments!" << std::endl << std::endl;
            PrintHelp(argv[0]);
            exit(1);
        }
        return(0);
    }

    // too less arguments
    if (argc<4)
    {
        std::cout << "Need at least three arguments!" << std::endl << std::endl;
        PrintHelp(argv[0]);
        exit(1);
    }

    // too much arguments
    if (argc>5)
    {
        std::cout << "Need at most four arguments!" << std::endl << std::endl;
        PrintHelp(argv[0]);
        exit(1);
    }

    ConverterBase::OptionID option=ConverterBase::ID_OPTION_NONE;

    wxString input, output, filename;

    for (int i=1; i<argc; i++)
    {
        tempStr=wxString::FromUTF8(argv[i]);

        if (tempStr.StartsWith(_T("-i=")))
        {   // input

            input=tempStr.Right(tempStr.Len()-3);

            if (input!=_T("html") && input!=_T("moin") && input!=_T("bb"))
            {
                std::cout << "Unknown input method: " << argv[i] << std::endl << std::endl;
                PrintHelp(argv[0]);
                exit(1);
            }

        }
        else if (tempStr.StartsWith(_T("-o=")))
        {   // output

            output=tempStr.Right(tempStr.Len()-3);

            if (output!=_T("html") && output!=_T("moin") && output!=_T("bb"))
            {
                std::cout << "Unknown ouput method: " << argv[i] << std::endl << std::endl;
                PrintHelp(argv[0]);
                exit(1);
            }

        }
        else if (tempStr.StartsWith(_T("-O=")))
        {   // option

            tempStr=tempStr.Right(tempStr.Len()-3);

            if (tempStr==_T("none"))
            {
                option=ConverterBase::ID_OPTION_NONE;
            }
            else if (tempStr==_T("uu"))
            {
                option=ConverterBase::ID_OPTION_UU;
            }
            else if (tempStr==_T("blog"))
            {
                option=ConverterBase::ID_OPTION_BLOG;
            }
            else
            {
                std::cout << "Unknown option: " << argv[i] << std::endl << std::endl;
                PrintHelp(argv[0]);
                exit(1);
            }
        }
        else if (tempStr.StartsWith(_T("-")))
        {   // unknown argument
            std::cout << "Unknown argument: " << argv[i] << std::endl << std::endl;
            PrintHelp(argv[0]);
            exit(1);
        }
        else
        {
            if (filename.IsEmpty())
            {
                filename=wxString::FromUTF8(argv[i]);
            }
            else
            {
                std::cout << "Filename already given!" << std::endl << std::endl;
                PrintHelp(argv[0]);
                exit(1);
            }
        }
    }

    if (filename.IsEmpty())
    {
        std::cout << "Filename not given!" << std::endl << std::endl;
        PrintHelp(argv[0]);
        exit(1);
    }

    // open file
    wxTextFile file(filename);
    if (!file.Open())
    {
        std::cout << "Could not open file " << (const char*)filename.mb_str(wxConvUTF8) << std::endl << std::endl;
        exit(1);
    }

    // convert to array
    wxArrayString text;
    for ( tempStr = file.GetFirstLine(); !file.Eof(); tempStr = file.GetNextLine() )
    {
        text.Add(tempStr);
    }

    // close file
    file.Close();

    // create converter
    ConverterBase conv(text);

    if (input==_T("html") && output==_T("bb"))
    {
        conv.ConvertHTML2BB(option);
    }
    else if (input==_T("html") && output==_T("moin"))
    {
        conv.ConvertHTML2Moin(option);
    }
    else if (input==_T("bb") && output==_T("html"))
    {
        conv.ConvertBB2HTML(option);
    }
    else if (input==_T("bb") && output==_T("moin"))
    {
        conv.ConvertBB2Moin(option);
    }
    else if (input==_T("moin") && output==_T("html"))
    {
        conv.ConvertMoin2HTML(option);
    }
    else if (input==_T("moin") && output==_T("bb"))
    {
        conv.ConvertMoin2BB(option);
    }

    text=conv.GetText();

    // give text out
    for (size_t i=0; i<text.GetCount(); i++)
    {
         std::cout << (const char*)text[i].mb_str(wxConvUTF8);
    }
    std::cout << std::endl;

    return(0);
}
